# SPOOKY_SWAP
SPOOKY_SWAP_ROUTER_ADDRESS = "0xF491e7B69E4244ad4002BC14e878a34207E38c29"
SPOOKY_SWAP_FACTORY_ADDRESS = "0x152eE697f2E276fA89E96742e9bB9aB1F2E61bE3"


# SPOOKY_SWAP_TESTNET
SPOOKY_SWAP_FACTORY_TESTNET_ADDRESS = "0xEE4bC42157cf65291Ba2FE839AE127e3Cc76f741"
SPOOKY_SWAP_ROUTER_TESTNET_ADDRESS = "0xa6AD18C2aC47803E193F75c3677b14BF19B94883"

# SPIRIT_SWAP
SPIRIT_SWAP_FACTORY_ADDRESS = "0xEF45d134b73241eDa7703fa787148D9C9F4950b0"
SPIRIT_SWAP_ROUTER_ADDRESS = "0x16327E3FbDaCA3bcF7E38F5Af2599D2DDc33aE52"

# SUSHI_SWAP
SUSHI_SWAP_FACTORY_ADDRESS = "0xc35DADB65012eC5796536bD9864eD8773aBc74C4"
SUSHI_SWAP_ROUTER_ADDRESS = "0x1b02dA8Cb0d097eB8D57A175b88c7D8b47997506"

# BEETHOVEN
BEETHOVEN_VAULT_ADDRESS = "0x20dd72Ed959b6147912C2e529F0a0C651c33c9ce"
BEETHOVEN_WEIGHTEDPOOLFACTORY_ADDRESS = "0x60467cb225092cE0c989361934311175f437Cf53"
BEETHOVEN_WEIGHTEDPOOL2TOKENSFACTORY_ADDRESS = (
    "0x92b377187bcCC6556FceD2f1e6DAd65850C20630"
)
